Documentation
¶
Index ¶
- func Equal(t *testing.T, expected, actual interface{}, msg ...interface{})
- func Error(t *testing.T, err error, msg ...interface{})
- func Expect(t *testing.T, input string, expected interface{})
- func Fail(t *testing.T, msg ...interface{})
- func False(t *testing.T, v bool, msg ...interface{})
- func IsType(t *testing.T, expected, actual interface{}, msg ...interface{})
- func Nil(t *testing.T, v interface{}, msg ...interface{})
- func NoError(t *testing.T, err error, msg ...interface{})
- func NotNil(t *testing.T, v interface{}, msg ...interface{})
- func Object(v interface{}) vm.Object
- func True(t *testing.T, v bool, msg ...interface{})
- type ARR
- type CallRes
- type IARR
- type IMAP
- type MAP
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Expect ¶
Expect runs the input script and asserts that the value of "out" is equal to expected.
Types ¶
type CallRes ¶
CallRes is a helper struct for chaining calls to module functions and asserting results.
func (CallRes) Call ¶
Call calls a function on the result of a previous call and returns a new CallRes for chaining.
func (CallRes) Expect ¶
func (c CallRes) Expect(expected interface{}, msgAndArgs ...interface{})
Expect asserts that the result of the previous call is equal to expected and that no error occurred.
func (CallRes) ExpectError ¶
func (c CallRes) ExpectError()
ExpectError asserts that the previous call resulted in an error.
func (CallRes) ExpectNoError ¶
func (c CallRes) ExpectNoError()
ExpectNoError asserts that the previous call did not result in an error.
Click to show internal directories.
Click to hide internal directories.